@@ -9,7 +9,7 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
@@ -19,23 +19,41 @@
 
 # Originally written by John Collins <jmc@xisl.com>.
 
-import filebuf, ipp, conf, subprocess, sys, os, stat, socket, threading, re, time, signal
+import filebuf, ipp, conf, subprocess, sys, os, stat, socket, select, threading, re, time, signal, syslog, errno
 
 # Get us a job id in case gspl-pr doesn't give one
 
 Next_jobid = os.getpid()
 Jobid_lock = threading.Lock()
 
+Var_run = "/var/run/cups"
+Procid_file = "cupsd.pid"
+
 # Thread-safe get job ID
 
 def get_next_jobid():
     """Get next job id"""
+    global Next_jobid
     Jobid_lock.acquire()
     result = Next_jobid
     Next_jobid += 1
     Jobid_lock.release()
     return result
 
+Pending_jobs = dict()
+
+class pend_job:
+    """Hold details of pending job"""
+
+    def __init__(self, p, u, t, c):
+	global Pending_jobs
+	self.jobnum = get_next_jobid()
+        self.pname = p
+        self.uname = u
+        self.title = t
+        self.copies = c
+        Pending_jobs[self.jobnum] = self
+
 # Set up default attribute values
 
 default_attr_values = {'attributes-charset': 'utf-8',
@@ -114,23 +132,26 @@ try:
     if len(sys.argv) > 1:
         Cfile = sys.argv[1]
     Config_data.parse_conf_file(Cfile)
-except conf.ConfError, msg:
-    sys.exit(msg.message)
+except conf.ConfError as msg:
+    sys.exit(msg.args[0])
 
 # Now for the meat of the stuff
 
 class CupsError(Exception):
     def __init__(self, code, msg):
+        Exception.__init__(self, msg)
         self.codename = code
-        self.message = msg
 
 # Util routines
 
-def copy_or_default(req, name):
+def copy_or_default(req, name, blank_def = False):
     """Copy field from request or supply default"""
     val = req.find_attribute(name)
     if val:
         res = val.get_value()
+        if blank_def:
+            res = res.strip()
+            if len(res) == 0: res = default_attr_values[name]           
     else:
         res = default_attr_values[name]
     return  res
@@ -154,6 +175,7 @@ def opgrp_hdr(req):
 def ipp_ok(req):
     """Report that everything went OK with IPP request
 (Even if nothing was done)"""
+    syslog.syslog(syslog.LOG_NOTICE, "No-op OK response to op %s" % ipp.op_to_name[req.statuscode])
     response = ipp.ipp()
     response.setrespcode(ipp.IPP_OK, req.id)
     response.pushvalue(opgrp_hdr(req))
@@ -163,6 +185,7 @@ def ipp_ok(req):
 
 def ipp_status(req, code, msg):
     """Deliver a status message back to sender"""
+    syslog.syslog(syslog.LOG_WARNING, "Op code %s returning result %s - %s" % (ipp.op_to_name[req.statuscode], code, msg))
     response = ipp.ipp()
     response.setrespcode(code, req.id)  # If code is a string it gets converted
     opgrp = opgrp_hdr(req)
@@ -208,8 +231,6 @@ def get_req_user_name(req):
 
 def validate_job(req):
     return ipp_ok(req)
-def cancel_job(req):
-    return ipp_ok(req)
 def get_jobs(req):
     return ipp_ok(req)
 def hold_job(req):
@@ -290,6 +311,9 @@ def move_job(req):
     return ipp_ok(req)
 def authenticate_job(req):
     return ipp_ok(req)
+# Get notifications seems to be required in some cases
+def get_notifications(req):
+    return ipp_ok(req)
 
 # The next operations we return some kind of error message
 # to tell the client we didn't do it.
@@ -304,8 +328,6 @@ def get_subscription_attributes(req):
     return  ipp_status(req, 'IPP_NOT_FOUND', 'Invalid notify-subscription-id')
 def get_subscriptions(req):
     return  ipp_status(req, 'IPP_NOT_FOUND', 'No subscriptions found')
-def get_notifications(req):
-    return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'get notifications not implemented')
 def send_notifications(req):
     return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'send notifications not implemented')
 def get_print_support_files(req):
@@ -408,8 +430,8 @@ def get_printer_attributes(req):
     """Get_printer_attributes request"""
     try:
         pname = get_pname_from_uri(req)
-    except CupsError, err:
-        return  ipp_status(req, err.codename, err.message)
+    except CupsError as err:
+        return  ipp_status(req, err.codename, err.args[0])
 
     # Get the list of requested attributes from the request
     req_al = req.find_attribute('requested-attributes')
@@ -429,69 +451,53 @@ def get_default(req):
     except:
         return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'Error in get_default()')
 
-def print_error(req, pname, code, ste):
-    """Generate return code from print"""
+def created_job_ok(req, pname, jobnum):
+    """Return response that job was created OK"""
 
-    msg = "%s gave exit code %d" % (pname, code)
-    if len(ste) != 0:
-            msg += " - " + ste
-    return ipp_status(req, 'IPP_NOT_POSSIBLE', msg)
+    response = ipp.ipp()
+    response.setrespcode(ipp.IPP_OK, req.id)
+    opgrp = opgrp_hdr(req)
+    msg = ipp.ippvalue(ipp.IPP_TAG_TEXT)
+    msg.setnamevalues('status-message', 'successful-ok')
+    opgrp.setvalue(msg)
+    response.pushvalue(opgrp)
 
-def print_job(req):
-    """Actually print a job"""
+    jobgrp = ipp.ippgroup(ipp.IPP_TAG_JOB)
+    idval = ipp.ippvalue(ipp.IPP_TAG_INTEGER)
+    idval.setnamevalues('job-id', jobnum)
+    jobgrp.setvalue(idval)
+    iduri = "ipp://%s/%s/%d" % (socket.gethostname(), pname, jobnum)
+    idval = ipp.ippvalue(ipp.IPP_TAG_URI)
+    idval.setnamevalues('job-uri', iduri)
+    jobgrp.setvalue(idval)
+    jobstat = ipp.ippvalue(ipp.IPP_TAG_ENUM)
+    jobstat.setnamevalues('job-state', ipp.IPP_JOB_PROCESSING)
+    jobgrp.setvalue(jobstat)
+    response.pushvalue(jobgrp)
+    return response.generate()
 
-    # Get printer name
-    try:
-        pname = get_pname_from_uri(req)
-	uname = get_req_user_name(req)
-    except CupsError, err:
-        return  ipp_status(req, err.codename, err.message)
+class print_err(Exception):
+    """Throw me if print error happens"""
 
-    title = copy_or_default(req, 'job-name')
-    copies = copy_or_default(req, 'copies')
+    def __init__(self, c, ste, *args):
+        Exception.__init__(self, *args)
+        self.code = c
+        self.stderr = ste
 
-    # We are assuming that the content-length field gave us the whole lot
+def process_print(req, pname, copies, title, user):
+    """Perform the operation to do the print and return the job id.
 
-    command = Config_data.print_command(pname)
+Throw a print_error if something goes wrong"""
+
+    command = Config_data.print_command(pname, copies=copies, title=title, user=user)
     if command is None:
-        return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'No print command for ' + pname)
-
-    # Put quotes round title if needed
-
-    if  re.search("\s", title):
-        title = "'" + title + "'"
-
-    # Set up copies, title and user parameters
-    # If something goes wrong just obliterate them
-
-    try:
-        cpres = Config_data.copies_param(pname) % copies
-        copies = " " + cpres
-        tres = Config_data.title_param(pname) % title
-        title = " " + tres
-	ures = Config_data.user_param(pname) % uname
-	uname = " " + ures
-    except TypeError:
-        copies = ""
-        title = ""
-	uname = ""
-
-    # Append those to command
-
-    command += copies
-    command += title
-    command += uname
-
-    # Now do the business
+        raise print_err('No print command for ' + pname)
 
     outf = subprocess.Popen(command, shell=True, stdin=subprocess.PIPE, stderr=subprocess.PIPE)
-
-    # See if something went wrong at that point
-
     pl = outf.poll()
     if pl:
         (sto, ste) = outf.communicate()
-        return print_error(req, pname, pl, ste)
+        raise print_err(pl, ste)
 
     # Send the data
 
@@ -503,28 +509,35 @@ def print_job(req):
         except:
             outf.terminate()
             (sto, ste) = outf.communicate()
-            raise
+            raise print_err(256, 'Input error on socket')
 
         # End of data is signified by zero length
         # Other errors raise filebufEOF
 
         if  len(b) == 0:
             break
-        sti.write(b)
+        try:
+            sti.write(b)
+        except IOError as err:
+            if err.args[0] == errno.EPIPE:
+                raise print_err(err.args[0], "Is spooler running")
+            else:
+                msg = "Pipe IO Error: " + err.args[1] + "(" + err.args[0] + ")"
+                raise print_err(err.args[0], msg)
 
         # Check it's still running
 
         pl = outf.poll()
         if  pl:
             (sto, ste) = outf.communicate()
-            return print_error(req, pname, pl, ste)
+            raise print_err(pl, ste)
 
     # Check we didn't get error message
 
     (sto, ste) = outf.communicate()
     pl = outf.wait()
     if pl:
-        return print_error(req, pname, pl, ste)
+        raise print_err(pl, ste)
 
     # Look for job id on std error and if present use it
     # Otherwise generate
@@ -538,29 +551,55 @@ def print_job(req):
     else:
         jobid = get_next_jobid()
 
-    # Now generate OK response
+    return jobid
 
-    response = ipp.ipp()
-    response.setrespcode(ipp.IPP_OK, req.id)
-    opgrp = opgrp_hdr(req)
-    msg = ipp.ippvalue(ipp.IPP_TAG_TEXT)
-    msg.setnamevalues('status-message', 'successful-ok')
-    opgrp.setvalue(msg)
-    response.pushvalue(opgrp)
 
-    jobgrp = ipp.ippgroup(ipp.IPP_TAG_JOB)
-    idval = ipp.ippvalue(ipp.IPP_TAG_INTEGER)
-    idval.setnamevalues('job-id', jobid)
-    jobgrp.setvalue(idval)
-    iduri = "ipp://%s/%s/%d" % (socket.gethostname(), pname, jobid)
-    idval = ipp.ippvalue(ipp.IPP_TAG_URI)
-    idval.setnamevalues('job-uri', iduri)
-    jobgrp.setvalue(idval)
-    jobstat = ipp.ippvalue(ipp.IPP_TAG_ENUM)
-    jobstat.setnamevalues('job-state', ipp.IPP_JOB_PENDING)
-    jobgrp.setvalue(jobstat)
-    response.pushvalue(jobgrp)
-    return response.generate()
+def print_error(req, pname, code, ste):
+    """Generate return code from print"""
+
+    msg = "%s gave exit code %d" % (pname, code)
+    if len(ste) != 0:
+            msg += " - " + ste
+    return ipp_status(req, 'IPP_NOT_POSSIBLE', msg)
+
+def print_job(req):
+    """Actually print a job"""
+    # Get printer name
+    try:
+        pname = get_pname_from_uri(req)
+	uname = get_req_user_name(req)
+    except CupsError as err:
+        return  ipp_status(req, err.codename, err.args[0])
+
+    title = copy_or_default(req, 'job-name', True)
+    copies = copy_or_default(req, 'copies')
+
+    try:
+        jobid = process_print(req, pname, copies, title, uname)
+    except print_err as err:
+        return print_error(req, pname, err.code, err.stderr)
+    return created_job_ok(req, pname, jobid)
+
+def extract_jobid(reqop):
+    """Extract job id from a request (send-document or cancel job)"""
+    # Spec says it might be given as a URI or as a job number (and printer name which we don't need)
+    jobid = reqop.find_attribute('job-id')
+    if jobid:
+        jobid = jobid.get_value()
+    else:
+        juri = reqop.find_attribute('job-uri')
+        if not juri:
+            raise CupsError('IPP_BAD_REQUEST', 'Missing required job-id or job-uri')
+        m = re.match("ipp://.*/.*/(\d+)", juri.get_value())
+        if not m:
+            raise CupsError('IPP_BAD_REQUEST', 'Invalid format job-uri ' + juri)
+        jobid = m.group(1)
+    # Convert jobid to numeric and look up
+    try:
+        jobid = int(jobid)
+    except ValueError:
+        raise CupsError('IPP_BAD_REQUEST', 'Invalid non-integer jobid ' + jobid)
+    return jobid
 
 # We believe that these don't happen
 
@@ -569,12 +608,48 @@ def print_uri(req):
     return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'print_uri not implemented')
 
 def create_job(req):
-    """Dont do create_job as it doesn't seem to be used"""
-    return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'create_job not implemented')
+    """Create job routine now has to be implemented"""
+    # Get printer name
+    try:
+        pname = get_pname_from_uri(req)
+	uname = get_req_user_name(req)
+    except CupsError as err:
+        return  ipp_status(req, err.codename, err.args[0])
+
+    pj = pend_job(pname, uname, copy_or_default(req, 'job-name', True), copy_or_default(req, 'copies'))
+    return created_job_ok(req, pname, pj.jobnum)
 
 def send_document(req):
-    """Dont do send_document as it doesn't seem to be used"""
-    return  ipp_status(req, 'IPP_INTERNAL_ERROR', 'send_document not implemented')
+    """Send document to pending job created by create job"""
+
+    # Find out the job number this is associated with
+
+    reqop = req.values[0]
+    jobid = extract_jobid(reqop)
+    if jobid not in Pending_jobs:
+        raise CupsError('IPP_NOT_FOUND', 'Job id not found in send-doc ' + str(jobid))
+    pj = Pending_jobs[jobid]
+
+    # If last document set, delete from pending
+
+    lastdoc = reqop.find_attribute('last-document')
+    if not lastdoc:
+        raise CupsError('IPP_BAD_REQUEST', 'No last-doc attribute')
+    if lastdoc.get_value():
+        del Pending_jobs[jobid]
+    try:
+        process_print(req, pj.pname, pj.copies, pj.title, pj.uname)
+    except print_err as err:
+        return print_error(req, pj.pname, err.code, err.stderr)
+    return created_job_ok(req, pj.pname, jobid)
+
+def cancel_job(req):
+    """Cancel job - dont worry if not pending"""
+    reqop = req.values[0]
+    jobid = extract_jobid(reqop)
+    if jobid in Pending_jobs:
+        del Pending_jobs[jobid]
+    return ipp_ok(req)
 
 # Lookup for operations
 
@@ -643,21 +718,46 @@ functab = dict(IPP_PRINT_JOB=print_job,
 
 def process_get(f, l):
     """Process a http get request"""
+
+    # First read up to end of request
+
+    while 1:
+        line = f.readline()
+        if line is None:
+            break
+        line = line.rstrip()
+        if len(line) == 0:
+            break
+
+    # Try to parse the starting line
+
     m = re.match("GET\s+/printers/(.+)\s+HTTP", l)
     if not m:
+        syslog.syslog(syslog.LOG_ERR, "Get request no match in %s" % l)
         return
+
+    # Try to open the file
+
     pf = None
     for ptr in (m.group(1), Config_data.default_printer() + ".ppd", "Default.ppd"):
         try:
-            pf = open(os.path.join(Config_data.ppddir, ptr), "rb")
+            fn = os.path.join(Config_data.ppddir, ptr)
+            pf = open(fn, "rb")
+            if Config_data.loglevel > 2:
+                syslog.syslog(syslog.LOG_INFO, "Opened .ppd file %s" % fn)
             break
         except:
             pass
 
-    if not pf:
-        return
+    if pf:
+        st = os.fstat(pf.fileno())
+        tim = time.ctime(st[stat.ST_MTIME])
+        fsize = st[stat.ST_SIZE]
+    else:
+        tim = time.time()
+        fsize = 0
+        syslog.syslog(syslog.LOG_ERR, "Get request file not found for %s" % m.group(1))
 
-    st = os.fstat(pf.fileno())
     f.write("HTTP/1.1 200 OK\n")
     f.write("Date: %s\n" % time.ctime())
     f.write("Server: CUPS/1.2\n")
@@ -665,122 +765,90 @@ def process_get(f, l):
     f.write("Keep-Alive: timeout=60\n")
     f.write("Content-Language: en_US\n")
     f.write("Content-Type: application/vnd.cups-ppd\n")
-    f.write("Last-Modified: %s\n" % time.ctime(st[stat.ST_MTIME]))
-    f.write("Content-Length: %d\n\n" % st[stat.ST_SIZE])
-    f.flush()
-    ffno = f.fileno()
-    while 1:
-        buf = pf.read(1024)
-        lb = len(buf)
-        if lb == 0:
-            break
-        # Do write taking into account everything doesn't get
-        # written at once
-        while lb > 0:
-            lw = os.write(ffno, buf)
-            buf = buf[lw:]
-            lb -= lw
-    pf.close()
+    f.write("Last-Modified: %s\n" % tim)
+    f.write("Content-Length: %d\n\n" % fsize)
+
+    if pf:
+        while 1:
+            buf = pf.read(1024)
+            lb = len(buf)
+            if lb == 0:
+                break
+            f.write(buf)
+        pf.close()
 
 def process_post(f):
     """Process an HTTP POST request"""
+
     ipplength=0
+    exp = False
+    chnk = False
+
+    # Read rest of header
+
     while 1:
         line = f.readline()
+        if line is None:
+            return
+
         l = line.rstrip()
         if  len(l) == 0:
             break
+
         m = re.search('Content-Length:\s*(\d+)', l, re.I)
         if m:
             ipplength=int(m.group(1))
-    if ipplength==0:
-        return None
-    return  filebuf.filebuf(f, ipplength)
+            continue
 
-def parsefd(f):
-    """Parse an incoming request with HTTP header"""
-    # Get first line which should be either HTTP request or just the start of a header
-
-    try:
-        line = f.readline()
-        l = line.strip()
-        if len(l) == 0:
-            return None
-        m = re.match("(GET|PUT|POST|DELETE|TRACE|OPTIONS|HEAD)\s", l)
+        m = re.match('Expect:', l, re.I)
         if m:
-            op = m.group(1)
-            if op == "GET":
-                process_get(f, l)
-                return None
-            elif op == "POST":
-                return process_post(f)
-            else:
-                print "Dont know how to handle " + op + " http ops"
-        else:
-            print "No match for HTTP op"
-    except socket.error, filebuf.filebufEOF:
-        return None
-    return None
+            exp = True
+            continue
 
-def parsefile(fname):
-    """Parse a file with an IPP in"""
-    try:
-        f = open(fname, 'rb')
-    except IOError:
-        return None
-    res = parsefd(f)
-    f.close()
-    return  res
+        m = re.match('Transfer-Encoding:\s+chunked', l, re.I)
+        if m:
+            chnk = True
 
-# Do the business in a thread
+    # If we've had a request to request more, satisfy it
 
-def cups_proc(conn, addr):
-    """Process a connection and handle request"""
-    f = conn.makefile("r+")
-    conn.close()
+    if exp:
+        f.write("HTTP/1.1 100 Continue\r\n\r\n")
 
-    # parsefd returns None if anything other than an IPP request,
-    # in which case it returns a filebuf
-
-    fb = parsefd(f)
-    if not fb:
-        f.close()
-        return
+    if chnk:
+        f.set_chunked()
+    else:
+        if ipplength == 0:
+            syslog.syslog(syslog.LOG_ERR, "No POST data")
+            return
+        f.set_expected(ipplength)
 
     # Parse IPP request
-    ipr = ipp.ipp(fb)
+
+    ipr = ipp.ipp(f)
     try:
         ipr.parse()
-    except ipp.IppError, mm:
-        f.close()
+        if Config_data.loglevel > 3:
+            ipr.display()
+    except ipp.IppError as mm:
         return
 
-    # Get code and select function
-
-    if Config_data.loglevel > 1:
-        ipr.display()
-
     iprcode = ipr.statuscode
 
     try:
         iprname = ipp.op_to_name[iprcode]
-        if  Config_data.loglevel == 1:
-            print "Op received:", iprname
+        syslog.syslog(syslog.LOG_INFO, "Request operation %s" % iprname)
         func = functab[iprname]
     except KeyError:
-        f.close()
         return
 
     # Actually do the business and return an IPP string (filebuf is a structure member)
 
     resp = func(ipr)
-    if  Config_data.loglevel > 0:
+    
+    if  Config_data.loglevel > 2:
         ipresp = ipp.ipp(filebuf.stringbuf(resp, 0))
         ipresp.parse()
-        if  Config_data.loglevel == 1:
-            print "Reply sent:" , ipp.resp_to_name(ipresp.statuscode)
-        else:
-            ipresp.display(1)
+        syslog.syslog(syslog.LOG_INFO, "Reply sent %s" % ipp.resp_to_name[ipresp.statuscode])
 
     # Now decorate the response
 
@@ -793,25 +861,152 @@ def cups_proc(conn, addr):
     f.write("Content-Type: application/ipp\r\n")
     f.write("Content-Length: %d\r\n\r\n" % len(resp))
     f.write(resp)
-    f.close()
+
+def parsefd(fd):
+    """Parse incoming requests with HTTP header"""
+
+    while 1:
+
+        # Get first line which should be an HTTP request
+
+        try:
+            line = fd.readline()
+            if line is None:
+                return
+            l = line.strip()
+            if len(l) == 0:
+                return
+
+            m = re.match("(GET|PUT|POST|DELETE|TRACE|OPTIONS|HEAD)\s", l)
+            if m:
+                op = m.group(1)
+                if op == "GET":
+                    process_get(fd, l)
+                elif op == "POST":
+                    process_post(fd)
+                else:
+                    syslog.syslog(syslog.LOG_ERR, "Dont know how to handle %s http ops" % op)
+                    return
+            else:
+                syslog.syslog(syslog.LOG_ERR, "No match for HTTP op")
+                return
+        except (socket.error, filebuf.filebufEOF):
+            syslog.syslog(syslog.LOG_DEBUG, "Had EOF on socket")
+            return
+
+# Do the business in a thread
+
+def cups_proc(conn, addr):
+    """Process a connection and handle request"""
+    fd = filebuf.httpfilebuf(conn, Config_data.timeouts)
+    parsefd(fd)
+    conn.close()
 
 # Meat of the thing
 
 def cups_server():
     """Accept connections on socket from people wanting to print stuff"""
-    try:
-        port = socket.getservbyname('ipp', 'tcp')
-        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-        s.bind(('', port))
-        s.listen(5)
-    except socket.error:
-        sys.exit("Socket errors - is CUPS running?")
+    s = None
+    port = socket.getservbyname('ipp', 'tcp')
+
+    # Try to support ipv6 and ipv4
+
+    socklist = []
+    poss_socks = socket.getaddrinfo(None, port, socket.AF_UNSPEC, socket.SOCK_STREAM, 0, socket.AI_PASSIVE)
+    act_socks = []
+
+    # First find AF_INET6 if it's there
+    # Unlike the advertising it might be anywhere
+    # Then find AF_INET
+
+    for afam in (socket.AF_INET6, socket.AF_INET):
+        for p in poss_socks:
+            af, socktype, proto, canonname, sa = p
+            if af == afam:
+                act_socks.append(p)
+                break
+
+    for p in  act_socks:
+        af, socktype, proto, canonname, sa = p
+        try:
+            s = socket.socket(af, socktype, proto)
+        except socket.error, msg:
+            continue
+
+        try:
+            s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+            s.bind(sa)
+            s.listen(5)
+
+        except socket.error as msg:
+            if msg.args[0] == errno.EACCES:
+                sys.exit("Cannot access socket - no permission")
+
+            # We may get EADDRINUSE from IPV4 if we've just set up IPV6 which we ignore
+            if msg.args[0] == errno.EADDRINUSE and len(socklist) == 0 and af != socket.AF_INET:
+                sys.exit("Socket in use - is CUPS running?")
+
+            s.close()
+            continue
+
+        socklist.append(s)
+
+    # If no success, abort
+    if len(socklist) == 0:
+        sys.exit("Sorry cannot start - unable to allocate socket?")
+
     while 1:
-        connaddr = s.accept()
-        th = threading.Thread(target=cups_proc, args=connaddr)
-        th.daemon = True
-        th.start()
+        rlist,wlist,xlist = select.select(socklist,(),())
+        for s in rlist:
+            connaddr = s.accept()
+            th = threading.Thread(target=cups_proc, args=connaddr)
+            th.daemon = True
+            th.start()
+
+def setup_pid():
+    """Setup pid entry in /var/run/cups/cupsd.pid
+
+Kill anything that's there already"""
+    file = Var_run + "/" + Procid_file
+    try:
+        st = os.stat(file)
+        if not stat.S_ISREG(st[stat.ST_MODE]):
+            sys.exit("Unknown type file " + file)
+        f = open(file, "rb")
+        pidstr = f.read(100)
+        f.close()
+        pid = int(pidstr)
+        os.kill(pid, signal.SIGTERM)
+        time.sleep(5)
+        try:
+            os.kill(pid, signal.SIGKILL)
+        except OSError:
+            pass
+        os.remove(file)
+    except (OSError, IOError, ValueError):
+        pass
+
+    # Create directory if needed
+    try:
+        os.mkdir(Var_run, 0755)
+    except OSError as err:
+        if err.args[0] != errno.EEXIST:
+            sys.exit("Cannot create " + Var_run + " " + err.args[1])
+    try:
+        f = open(file, "wb")
+        f.write(str(os.getpid()) + "\n")
+        f.close()
+    except IOError as err:
+        sys.exit("Cannot create " + file + " - " + err.args[1])
+
+def remove_pid(signum, frame):
+    """Remove pid entry in /var/run/cups/cupsd.pid"""
+    try:
+        os.remove(Var_run + '/' + Procid_file)
+    except OSError:
+        # Ignore errors
+        pass
+    sys.exit("CUPSPY terminated by signal")
 
 # Run the stuff
 
@@ -821,4 +1016,9 @@ if __name__ == "__main__":
     signal.signal(signal.SIGHUP, signal.SIG_IGN)
     if os.fork() != 0:
         os._exit(0)
+    syslog.openlog('cupspy', syslog.LOG_NDELAY|syslog.LOG_PID, syslog.LOG_LPR)
+    syslog.setlogmask(syslog.LOG_UPTO(Config_data.loglevel + syslog.LOG_ERR))
+    syslog.syslog(syslog.LOG_INFO, "Starting")
+    setup_pid()
+    signal.signal(signal.SIGTERM, remove_pid)
     cups_server()
