@@ -80,7 +80,6 @@ int	existing_subds,		/* Existing sub directories */
 	deadwood;		/* Number of jobs not in job list */
 
 char	*spdir;			/* Spool directory */
-uid_t	Daemuid;		/* User name */
 
 #define	SLURPSIZE	80
 #define	REBUILDJNAM	"Rebuild_jfile"
@@ -90,8 +89,6 @@ uid_t	Daemuid;		/* User name */
 
 /*	This are just to keep the library happy....*/
 
-FILE	*Cfile;
-
 void	nomem(void)
 {
 	fprintf(stderr, "Run out of memory\n");
@@ -951,7 +948,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	extern	int	optind;
 	extern	char	*optarg;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  (geteuid() != ROOTID)  {
 		fprintf(stderr, "Sorry, but you must run this as the super-user\n");
