@@ -51,20 +51,12 @@
 #include "cgiuser.h"
 #include "cgifndjb.h"
 #include "listperms.h"
-#ifdef	SHAREDLIBS
 #include "xfershm.h"
-#endif
 
 #ifndef	PATH_MAX
 #define	PATH_MAX	1024
 #endif
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-DEF_DISPOPTS;
-
 int	nopage = -1,
 	headerflag = -1;
 
@@ -82,23 +74,10 @@ char	bigbuff[200];
 
 char	*Curr_pwd;
 
-FILE	*Cfile;
-
 static	char	*localptr;
 
 #define	IPC_MODE	0600
 
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-#ifdef	SHAREDLIBS
-struct	xfershm		*Xfer_shmp;
-#endif
-
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-
 int	rdpgfile(const struct spq *, struct pages *, char **, unsigned *, LONG **);
 
 /* For when we run out of memory.....  */
@@ -716,7 +695,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 #if	defined(NHONSUID) || defined(DEBUG)
 	int_ugid_t	chk_uid;
 #endif
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.2 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
