@@ -47,11 +47,8 @@
 #include "incl_unix.h"
 #include "incl_ugid.h"
 #include "cfile.h"
-#ifdef	SHAREDLIBS
 #include "xfershm.h"
 #include "q_shm.h"
-#include "displayopt.h"
-#endif
 
 #ifndef	P_tmpdir
 #define	P_tmpdir	"/tmp/"
@@ -76,7 +73,6 @@ jmp_buf	ajb;
 #ifndef	ID_SWAP
 PIDTYPE	lastpid = -1;
 #endif
-uid_t	Realuid, Daemuid, Effuid;
 struct	spdet	*mypriv;
 jobno_t	jobn;
 netid_t		Out_host;
@@ -89,8 +85,6 @@ int	jobtimeout = 0;
 
 #define	JN_INC	80000		/*  Add this to job no if clashes */
 
-FILE	*Cfile;
-
 char	Sufchars[] = DEF_SUFCHARS;
 char	wotform[MAXFORM+1];
 int	wotl;
@@ -99,17 +93,6 @@ char	*Curr_pwd;
 
 char	tmpfl[L_tmpnam];
 
-#ifdef	SHAREDLIBS
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-struct	xfershm		*Xfer_shmp;
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-DEF_DISPOPTS;
-#endif
-
 int	spitoption(const int, const int, FILE *, const int, const int);
 int	proc_save_opts(const char *, const char *, void (*)(FILE *, const char *));
 int	remenqueue(const netid_t, const struct spq *, const struct pages *, const char *, FILE *, jobno_t *);
@@ -511,7 +494,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.2 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
