@@ -54,10 +54,7 @@
 #include "incl_ugid.h"
 #include "cfile.h"
 #include "extdefs.h"
-#ifdef	SHAREDLIBS
 #include "q_shm.h"
-#include "displayopt.h"
-#endif
 
 #ifndef	ROOTID
 #define	ROOTID	0
@@ -76,13 +73,12 @@ jmp_buf	ajb;
 #ifndef	ID_SWAP
 PIDTYPE	lastpid = -1;
 #endif
-uid_t	Realuid, Daemuid, Effuid;
+
 struct	spdet	*mypriv;
 struct	spr_req	sp_req;
 struct	spq	SPQ;
 jobno_t	jobn;
 netid_t		Out_host;	/* For re-routing to rspr */
-struct	xfershm		*Xfer_shmp;
 
 /* Default delimiter and length
    If these are unchanged we don't create a page file */
@@ -94,24 +90,12 @@ int	jobtimeout = 0;
 
 #define	JN_INC	80000		/*  Add this to job no if clashes */
 
-FILE	*Cfile;
-
 char	Sufchars[] = DEF_SUFCHARS;
 char	wotform[MAXFORM+1];
 int	wotl;
 
-int	Ctrl_chan = -1;
-#ifndef	USING_FLOCK
-int	Sem_chan = -1;
-#endif
 char	*Curr_pwd, *spdir, *tmpfl, *pgfl;
 
-#ifdef	SHAREDLIBS
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-DEF_DISPOPTS;
-#endif
-
 int	spitoption(const int, const int, FILE *, const int, const int);
 int	proc_save_opts(const char *, const char *, void (*)(FILE *, const char *));
 char	*spath(const char *, const char *);
@@ -755,7 +739,7 @@ MAINFN_TYPE	main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 		
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.2 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
